@@ -90,7 +90,7 @@ class ContextNode:
         Returns:
             A string that represents the object tree with detailed Node values.
         """
-        string = "{}Role={}, Name={}, VAN={}, Desc={}, St={}, Sts={}, at x={}:y={} w={} h={}; cc={}; vcc={}".format(
+        string = "{}Role={}, Name={}, VAN={}, Desc={}, St={}, Sts={}, at x={}:y={} w={} h={}; indexInParent={}; cc={}; vcc={}".format(
             '  ' * self.ancestry,
             repr(self.context_info.role),
             repr(self.context_info.name),
@@ -102,6 +102,7 @@ class ContextNode:
             self.context_info.y,
             self.context_info.width,
             self.context_info.height,
+            self.context_info.indexInParent,
             self.context_info.childrenCount,
             self.visible_children_count
         )
@@ -116,7 +117,7 @@ class ContextNode:
         Returns:
             A string of Node values.
         """
-        string = "Role={}, Name={}, VAN={}, Desc={}, St={}, Sts={}, at x={}:y={} w={} h={}; cc={}; vcc={}".format(
+        string = "Role={}, Name={}, VAN={}, Desc={}, St={}, Sts={}, at x={}:y={} w={} h={}; indexInParent={}; cc={}; vcc={}".format(
             repr(self.context_info.role),
             repr(self.context_info.name),
             repr(self.virtual_accessible_name),
@@ -127,6 +128,7 @@ class ContextNode:
             self.context_info.y,
             self.context_info.width,
             self.context_info.height,
+            self.context_info.indexInParent,
             self.context_info.childrenCount,
             self.visible_children_count
         )
@@ -151,7 +153,7 @@ class ContextNode:
     def _match_attrs(self, search_elements: List[SearchElement]) -> bool:
         for search_element in search_elements:
             attr = getattr(self._aci, search_element.name)
-            if isinstance(attr, str):
+            if isinstance(attr, str) and not search_element.strict:
                 if not attr.startswith(search_element.value):
                     return False
             else:
@@ -192,7 +194,7 @@ class ContextNode:
         Get all actions available for element
         """
         with self._lock:
-            return self.actions.list_actions
+            return self.actions.list_actions()
 
     def do_action(self, action: str) -> None:
         """
